Method: RubyExcel::Sheet#<<

Defined in:
lib/rubyexcel/sheet.rb

#<<(other) ⇒ self

Note:

When adding another Sheet it won’t import the headers unless this Sheet is empty.

Note:

Anything other than an an Array, Hash, Row, Column or Sheet will be appended to the first row

Append an object to the Sheet

Parameters:

  • other (Object)

    the object to append

Returns:

  • (self)


113
114
115
116
# File 'lib/rubyexcel/sheet.rb', line 113

def <<( other )
  data << other
  self
end